﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI.WebControls;
using WakeMeUp.repositorio;
using WakeMeUp.interfaceNegocio;
using WakeMeUp.basicas;
using WakeMeUp.exceptions;

namespace WakeMeUp.negocio
{
    public class NegocioUsuario : InterfaceNegocioUsuario
    {
        private RepUsuario repositorio;

        public NegocioUsuario() 
        {
            repositorio = new RepUsuario();
        }

        #region InterfaceNegocioUsuario Members
        public bool cadastrar(Usuario usuario) 
        {
            bool retorno = false;
            if (usuario == null)
            {
                throw new UsuarioInvalidoException();
            }
            else 
            {
                repositorio.cadastrar(usuario);
                retorno = true;
            }
            return retorno;
        }

        public bool editar(Usuario usuario)
        {
            bool retorno = false;
            if (usuario == null)
            {
                throw new UsuarioInvalidoException();
            }
            else
            {
                repositorio.editar(usuario);
                retorno = true;
            }
            return retorno;
        }

        public bool remover(Usuario usuario)
        {
            bool retorno = false;
            if (usuario == null)
            {
                throw new UsuarioInvalidoException();
            }
            else
            {
                repositorio.remover(usuario);
                retorno = true;
            }
            return retorno;
        }

        public bool adicionarAtividade(Atividade atividade, Usuario usuario)
        {
            bool retorno = false;
            if (atividade == null)
            {   
                throw new AtividadeInvalidaException();
            }
            else
            {
                if (usuario == null)
                {
                    throw new UsuarioInvalidoException();
                }
                else
                {
                    repositorio.adicionarAtividade(atividade, usuario);
                    retorno = true;
                }
                
            }
            return retorno;
        }

        public bool removerAtividade(Atividade atividade)
        {
            bool retorno = false;
            if (atividade == null)
            {
                throw new AtividadeInvalidaException();
            }
            else
            {            
                    repositorio.removerAtividade(atividade);
                    retorno = true;               
            }
            return retorno;
        }

        public bool adicionarMensagem(Mensagem mensagem, Usuario usuario)
        {
            bool retorno = false;
            if (mensagem == null)
            {
                throw new MensagemInvalidaException();
            }
            else
            {
                if (usuario == null)
                {
                    throw new UsuarioInvalidoException();
                }
                else
                {
                    repositorio.adicionarMensagem(mensagem, usuario);
                    retorno = true;
                }
                
            }
            return retorno;
        }

        public bool removerMensagem(Mensagem mensagem)
        {
            bool retorno = false;
            if (mensagem == null)
            {
                throw new MensagemInvalidaException();
            }
            else
            {
                    repositorio.removerMensagem(mensagem);
                    retorno = true;             
            }
            return retorno;
        }

        public bool adicionarMeta(Meta meta, Usuario usuario)
        {
            bool retorno = false;
            if (meta == null)
            {
                throw new MetaInvalidaException();
            }
            else
            {
                if (usuario == null)
                {
                    throw new UsuarioInvalidoException();
                }
                else
                {
                    repositorio.adicionarMeta(meta, usuario);
                    retorno = true;
                }       
            }
            return retorno;
        }

        public bool removerMeta(Meta meta)
        {
            bool retorno = false;
            if (meta == null)
            {
                throw new MetaInvalidaException();
            }
            else
            {           
                    repositorio.removerMeta(meta);
                    retorno = true;              
            }
            return retorno;
        }

        public bool adicionarPeso(Peso peso, Usuario usuario)
        {
            bool retorno = false;
            if (peso == null)
            {
                throw new MetaInvalidaException();
            }
            else
            {
                if (usuario == null)
                {
                    throw new UsuarioInvalidoException();
                }
                else
                {
                    repositorio.adicionarPeso(peso, usuario);
                    retorno = true;
                }  
                
            }
            return retorno;
        }

        public bool removerPeso(Peso peso)
        {
            bool retorno = false;
            if (peso == null)
            {
                throw new MetaInvalidaException();
            }
            else
            {
                    repositorio.removerPeso(peso);
                    retorno = true;                    
            }
            return retorno;
        }

        public bool adicionarRefeicao(Refeicao refeicao, Usuario usuario)
        {
            bool retorno = false;
            if (refeicao == null)
            {
                throw new RefeicaoInvalidaException();
            }
            else
            {
                if (usuario == null)
                {
                    throw new UsuarioInvalidoException();
                }
                else
                {
                    repositorio.adicionarRefeicao(refeicao, usuario);
                    retorno = true;
                }  
                
            }
            return retorno;
        }
        public bool removerRefeicao(Refeicao refeicao)
        {
            bool retorno = false;
            if (refeicao == null)
            {
                throw new RefeicaoInvalidaException();
            }
            else
            {           
                    repositorio.removerRefeicao(refeicao);
                    retorno = true;                  
            }
            return retorno;
        }
        public bool adicionarMotivador(Usuario motivador, Usuario motivado)
        {
            bool retorno = false;
            if (motivador == null)
            {
                throw new UsuarioInvalidoException();
            }
            else
            {
                if (motivado == null)
                {
                    throw new UsuarioInvalidoException();
                }
                else
                {
                    repositorio.adicionarMotivador(motivador, motivado);
                    retorno = true;
                }
            }
            return retorno;
        }
        public bool removerMotivador(Usuario motivador, Usuario motivado)
        {
            bool retorno = false;
            if (motivador == null)
            {
                throw new UsuarioInvalidoException();
            }
            else
            {
                if (motivado == null)
                {
                    throw new UsuarioInvalidoException();
                }
                else
                {
                    repositorio.removerMotivador(motivador, motivado);
                    retorno = true;
                }
                
            }
            return retorno;
        }
        public bool adicionarFoto(Usuario usuario, Foto foto) 
        {
            bool retorno = false;

            if (usuario == null)
            {
                throw new UsuarioInvalidoException();
            }
            else 
            {
                if (foto == null)
                {
                    throw new FotoInvalidaException();
                }
                else 
                {
                   
                   repositorio.adicionarFoto(usuario, foto);
                   retorno = true;
                }
            }

            return retorno;
        }
        public bool removerFoto(Foto foto) 
        {
            bool retorno = false;

                if (foto == null)
                {
                    throw new FotoInvalidaException();
                }
                else
                {
                   
                    repositorio.removerFoto(foto);
                    retorno = true;
                    
                }     
            return retorno;
        }
        public Usuario buscarPorLogin(Usuario usuario)
        {
            if (usuario == null)
            {
                throw new UsuarioInvalidoException();
            }
            else 
            {
                return repositorio.buscarPorLogin(usuario);
            }
           
        }

        public List<Atividade> buscarAtividades(Usuario usuario)
        {
            if (usuario == null)
            {
                throw new UsuarioInvalidoException();
            }
            else
            {
                return repositorio.buscarAtividades(usuario);
            }
        }

        public List<Mensagem> buscarMensagens(Usuario usuario)
        {
            if (usuario == null)
            {
                throw new UsuarioInvalidoException();
            }
            else
            {
                return repositorio.buscarMensagens(usuario);
            }
        }

        public List<Meta> buscarMetas(Usuario usuario)
        {
            if (usuario == null)
            {
                throw new UsuarioInvalidoException();
            }
            else
            {
                return repositorio.buscarMetas(usuario);
            }
        }

        public List<Peso> buscarPesos(Usuario usuario)
        {
            if (usuario == null)
            {
                throw new UsuarioInvalidoException();
            }
            else
            {
                return repositorio.buscarPesos(usuario);
            }
        }

        public List<Refeicao> buscarRefeicao(Usuario usuario)
        {
            if (usuario == null)
            {
                throw new UsuarioInvalidoException();
            }
            else
            {
                return repositorio.buscarRefeicao(usuario);
            }
        }

        public List<Usuario> buscarTodosMotivadores(Usuario motivado)
        {
            if (motivado == null)
            {
                throw new UsuarioInvalidoException();
            }
            else
            {
                return repositorio.buscarTodosMotivadores(motivado);
            }
        }

        public List<Foto> buscarFotos(Usuario usuario)
        {
            if (usuario == null)
            {
                throw new UsuarioInvalidoException();
            }
            else
            {
                return repositorio.buscarFotos(usuario);
            }
        }

        #endregion
    }
}
