﻿using System;
using System.Collections.Generic;
using System.Configuration;
using System.Data;
using System.Data.SqlClient;
using System.Drawing;
using System.Linq;
using System.Web;
using System.Web.UI.WebControls;
using WakeMeUp.basicas;
using WakeMeUp.repositorio;
using WakeMeUp.conexaoBD;
using WakeMeUp.interfaceRepositorio;

namespace WakeMeUp.repositorio
{
    public class RepUsuario : InterfaceRepUsuario
    {
        Conexao conexao;
        List<Usuario> _usuarios;

        public RepUsuario() 
        {
            this._usuarios = new List<Usuario>();
            this.conexao = Conexao.getInstancia();
        }

        #region InterfaceRepUsuario Members
        public void cadastrar(Usuario usuario)
        {//OK       
                SqlCommand mySqlCommand = new SqlCommand();
                mySqlCommand.CommandText = "INSERT INTO usuario VALUES (@Nome, @Sobrenome, @Email, @Login, @Nascimento, @Sexo, @Altura, @Senha)";
                mySqlCommand.Parameters.AddWithValue("@Nome", usuario.Nome);
                mySqlCommand.Parameters.AddWithValue("@Sobrenome", usuario.Sobrenome);
                mySqlCommand.Parameters.AddWithValue("@Email", usuario.Email);
                mySqlCommand.Parameters.AddWithValue("@Login", usuario.Login);
                mySqlCommand.Parameters.AddWithValue("@Nascimento", usuario.Nascimento);
                mySqlCommand.Parameters.AddWithValue("@Sexo", usuario.Sexo);
                mySqlCommand.Parameters.AddWithValue("@Altura", usuario.Altura);
                mySqlCommand.Parameters.AddWithValue("@Senha", usuario.Senha);

                conexao.executarQuery(mySqlCommand);
        }

        public void editar(Usuario usuario)
        {//OK
                SqlCommand mySqlCommand = new SqlCommand();
                mySqlCommand.CommandText = "UPDATE usuario SET nome = @Nome, sobrenome = @Sobrenome, email = @Email, login = @Login, nascimento = @Nascimento, sexo = @Sexo, altura = @Altura, senha = @Senha WHERE ID = @ID";
                mySqlCommand.Parameters.AddWithValue("@Nome", usuario.Nome);
                mySqlCommand.Parameters.AddWithValue("@Sobrenome", usuario.Sobrenome);
                mySqlCommand.Parameters.AddWithValue("@Email", usuario.Email);
                mySqlCommand.Parameters.AddWithValue("@Login", usuario.Login);
                mySqlCommand.Parameters.AddWithValue("@Nascimento", usuario.Nascimento);
                mySqlCommand.Parameters.AddWithValue("@Sexo", usuario.Sexo);
                mySqlCommand.Parameters.AddWithValue("@ID", usuario.Id);
                mySqlCommand.Parameters.AddWithValue("@Altura", usuario.Altura);
                mySqlCommand.Parameters.AddWithValue("@Senha", usuario.Senha);

                conexao.executarQuery(mySqlCommand);
        }

        public void remover(Usuario usuario)
        {//OK

            this.removerTodasAtividades(usuario);
            this.removerTodasMensagens(usuario);
            this.removerTodosPesos(usuario);
            this.removerTodasRefeicoes(usuario);
            this.removerTodasMetas(usuario);        
            this.removerTodosMotivadores(usuario);
            this.removerTodasFotos(usuario);

            SqlCommand mySqlCommand = new SqlCommand();
            mySqlCommand.CommandText = "DELETE FROM usuario WHERE id = @ID";
            mySqlCommand.Parameters.AddWithValue("@ID", usuario.Id);

            conexao.executarQuery(mySqlCommand);
            
        }

        public void adicionarAtividade(Atividade atividade, Usuario usuario)
        {//OK
            SqlCommand mySqlCommand = new SqlCommand();
            mySqlCommand.CommandText = "INSERT INTO atividade VALUES (@Tipo, @Duracao, @Intensidade, @CaloriasQueimadas, @Data, @IdUsuario)";
            mySqlCommand.Parameters.AddWithValue("@Tipo", atividade.Tipo);
            mySqlCommand.Parameters.AddWithValue("@Duracao", atividade.Duracao);
            mySqlCommand.Parameters.AddWithValue("@Intensidade", atividade.Intensidade);
            mySqlCommand.Parameters.AddWithValue("@CaloriasQueimadas", atividade.Calorias);
            mySqlCommand.Parameters.AddWithValue("@Data", atividade.Data);
            mySqlCommand.Parameters.AddWithValue("@IdUsuario", usuario.Id);

            conexao.executarQuery(mySqlCommand);
        }

        public void removerAtividade(Atividade atividade)
        {//OK
            SqlCommand mySqlCommand = new SqlCommand();
            mySqlCommand.CommandText = "DELETE FROM atividade WHERE IdAtividade = @ID";
            mySqlCommand.Parameters.AddWithValue("@ID", atividade.Id);

            conexao.executarQuery(mySqlCommand);
        }

        public void adicionarMensagem(Mensagem mensagem, Usuario usuario)
        {//OK
            SqlCommand mySqlCommand = new SqlCommand();
            mySqlCommand.CommandText = "INSERT INTO mensagem VALUES (@Texto, @Remetente, @Data, @IdUsuario)";
            mySqlCommand.Parameters.AddWithValue("@Texto", mensagem.Texto);
            mySqlCommand.Parameters.AddWithValue("@Remetente", mensagem.Remetente);
            mySqlCommand.Parameters.AddWithValue("@Data", mensagem.Data);
            mySqlCommand.Parameters.AddWithValue("@IdUsuario", usuario.Id);

            conexao.executarQuery(mySqlCommand);
        }

        public void removerMensagem(Mensagem mensagem)
        {//OK
            SqlCommand mySqlCommand = new SqlCommand();
            mySqlCommand.CommandText = "DELETE FROM mensagem WHERE idmensagem = @ID";
            mySqlCommand.Parameters.AddWithValue("@ID", mensagem.Id);

            conexao.executarQuery(mySqlCommand);   
        }

        public void adicionarMeta(Meta meta, Usuario usuario)
        {//OK
            SqlCommand mySqlCommand = new SqlCommand();
            mySqlCommand.CommandText = "INSERT INTO metas VALUES (@Descricao, @DataConquista, @FichaDeExercicios, @IdUsuario)";
            mySqlCommand.Parameters.AddWithValue("@Descricao", meta.Descricao);
            mySqlCommand.Parameters.AddWithValue("@DataConquista", meta.Data);
            mySqlCommand.Parameters.AddWithValue("@FichaDeExercicios", meta.Ficha);
            mySqlCommand.Parameters.AddWithValue("@IdUsuario", usuario.Id);

            conexao.executarQuery(mySqlCommand);  
        }

        public void removerMeta(Meta meta)
        {//OK
            SqlCommand mySqlCommand = new SqlCommand();
            mySqlCommand.CommandText = "DELETE FROM metas WHERE idMetas = @ID";
            mySqlCommand.Parameters.AddWithValue("@ID", meta.Id);

            conexao.executarQuery(mySqlCommand);   
        }

        public void adicionarPeso(Peso peso, Usuario usuario)
        {//OK
            SqlCommand mySqlCommand = new SqlCommand();
            mySqlCommand.CommandText = "INSERT INTO peso VALUES (@Kg, @Data, @IDUsuario)";
            mySqlCommand.Parameters.AddWithValue("@Kg", peso.Kilogramas);
            mySqlCommand.Parameters.AddWithValue("@Data", peso.Data);
            mySqlCommand.Parameters.AddWithValue("@IDUsuario", usuario.Id);      

            conexao.executarQuery(mySqlCommand);  
        }

        public void removerPeso(Peso peso) 
        {//OK
            SqlCommand mySqlCommand = new SqlCommand();
            mySqlCommand.CommandText = "DELETE FROM peso WHERE idPeso = @ID";
            mySqlCommand.Parameters.AddWithValue("@ID", peso.Id);

            conexao.executarQuery(mySqlCommand);   
        }

        public void adicionarRefeicao(Refeicao refeicao, Usuario usuario) 
        {//OK
            SqlCommand mySqlCommand = new SqlCommand();
            mySqlCommand.CommandText = "INSERT INTO refeicao VALUES (@CoposDeAgua, @Data, @Tipo, @QtdCalorias, @Descricao, @InfoNutricionais, @Nome, @IdUsuario)";
            mySqlCommand.Parameters.AddWithValue("@CoposDeAgua", refeicao.Copos_De_Agua);
            mySqlCommand.Parameters.AddWithValue("@Data", refeicao.Data);
            mySqlCommand.Parameters.AddWithValue("@Tipo", refeicao.Tipo);
            mySqlCommand.Parameters.AddWithValue("@QtdCalorias", refeicao.Calorias);
            mySqlCommand.Parameters.AddWithValue("@Descricao", refeicao.Descricao);
            mySqlCommand.Parameters.AddWithValue("@InfoNutricionais", refeicao.infoNutricionais);
            mySqlCommand.Parameters.AddWithValue("@Nome", refeicao.Nome);
            mySqlCommand.Parameters.AddWithValue("@IdUsuario", usuario.Id);

            conexao.executarQuery(mySqlCommand);
        }

        public void removerRefeicao(Refeicao refeicao) 
        {//OK
            SqlCommand mySqlCommand = new SqlCommand();
            mySqlCommand.CommandText = "DELETE FROM refeicao WHERE IdRefeicao = @IdRefeicao";
            mySqlCommand.Parameters.AddWithValue("@IdRefeicao", refeicao.Id);

            conexao.executarQuery(mySqlCommand);   
        }

        public void adicionarMotivador(Usuario motivador, Usuario motivado) 
        {//OK
            SqlCommand mySqlCommand = new SqlCommand();
            mySqlCommand.CommandText = "INSERT INTO motivacao VALUES (@IdMotivado, @IdMotivador)";
            mySqlCommand.Parameters.AddWithValue("@IdMotivado", motivado.Id);
            mySqlCommand.Parameters.AddWithValue("@IdMotivador", motivador.Id);

            conexao.executarQuery(mySqlCommand);   
        }

        public void removerMotivador(Usuario motivador, Usuario motivado) 
        {//OK
            SqlCommand mySqlCommand = new SqlCommand();
            mySqlCommand.CommandText = "DELETE FROM motivacao WHERE IdUsuarioMotivado = @IdMotivado and IdUsuarioMotivador = @IdMotivador";
            mySqlCommand.Parameters.AddWithValue("@IdMotivado", motivado.Id);
            mySqlCommand.Parameters.AddWithValue("@IdMotivador", motivador.Id);

            conexao.executarQuery(mySqlCommand);   
        }

        public void adicionarFoto(Usuario usuario, Foto foto)
        {//OK
            SqlCommand mySqlCommand = new SqlCommand();
         
            mySqlCommand.CommandText = "INSERT INTO foto VALUES(@descricao, @idUsuario,@arq)";
            mySqlCommand.Parameters.AddWithValue("@descricao", foto.Descricao);
            mySqlCommand.Parameters.AddWithValue("idUsuario", usuario.Id);
            mySqlCommand.Parameters.AddWithValue("@arq", foto.Imagem);

            conexao.executarQuery(mySqlCommand);
        }

        public void removerFoto(Foto foto) 
        {//OK
            SqlCommand mySqlCommand = new SqlCommand();
            mySqlCommand.CommandText = "DELETE FROM foto WHERE IDfoto = @IDfoto";
            mySqlCommand.Parameters.AddWithValue("@IDfoto", foto.ID);

            conexao.executarQuery(mySqlCommand);  
        }

        public Usuario buscarPorLogin(Usuario usuario) 
        {//OK
            Usuario retorno = new Usuario();
            SqlConnection connection = null;
            try
            {
                connection = conexao.getConnection();
                connection.Open();
                
                SqlDataReader dr = null;
                string sql = "SELECT * FROM usuario WHERE Login = @Login";
                SqlCommand mySqlCommand = new SqlCommand(sql, conexao.getConnection());
                mySqlCommand.Parameters.AddWithValue("@Login", usuario.Login);
                dr = mySqlCommand.ExecuteReader();

                if (dr.Read())
                {
                    string nome = (string)dr["Nome"];
                    string sobrenome = (string)dr["Sobrenome"];
                    string email = (string)dr["Email"];
                    DateTime nascimento = (DateTime)dr["Nascimento"];
                    int sexo = (int)dr["Sexo"];
                    double altura = (double)dr["Altura"];
                    string senha = (string)dr["Senha"];

                    retorno.Nome = nome;
                    retorno.Sobrenome = sobrenome;
                    retorno.Email = email;
                    retorno.Nascimento = nascimento;
                    retorno.Sexo = sexo;
                    retorno.Altura = altura;
                    retorno.Senha = senha;
                    retorno.Id = usuario.Id;
                }
            }
            finally 
            {
                if(connection != null)
                {
                    connection.Close();
                }             
            }

            List<Foto> album = this.buscarFotos(usuario);
            retorno.Album = album;

            return retorno; 
        }

        public List<Atividade> buscarAtividades(Usuario usuario) 
        { //OK
            List<Atividade> retorno = new List<Atividade>();
            SqlConnection connection = null;
            try
            {
                connection = conexao.getConnection();
                connection.Open();

                SqlDataReader dr = null;
                string sql = "SELECT * FROM atividade WHERE IdUsuario = @ID";
                SqlCommand mySqlCommand = new SqlCommand(sql, conexao.getConnection());
                mySqlCommand.Parameters.AddWithValue("@ID", usuario.Id);
                dr = mySqlCommand.ExecuteReader();

                while (dr.Read())
                {
                    Atividade atividade = new Atividade();
                    
                    string tipo = (string)dr["Tipo"];
                    int duracao = (int)dr["Duracao"];
                    int intensidade = (int)dr["Intensidade"];
                    int calorias = (int)dr["CaloriasQueimadas"];
                    DateTime data = (DateTime)dr["Data"];
                    int id = (int)dr["IdAtividade"];

                    atividade.Id = id;
                    atividade.Tipo = tipo;
                    atividade.Calorias = calorias;
                    atividade.Data = data;
                    atividade.Intensidade = intensidade;
                    atividade.Duracao = duracao;
                    
                    retorno.Add(atividade);
                }
            }
            finally 
            {
                if (connection != null)
                {
                    connection.Close();
                }  
            }
            return retorno;
        
        }

        public List<Mensagem> buscarMensagens(Usuario usuario) 
        {//OK
            List<Mensagem> retorno = new List<Mensagem>();
            SqlConnection connection = null;
            try
            {
                connection = conexao.getConnection();
                connection.Open();

                SqlDataReader dr = null;
                string sql = "SELECT * FROM mensagem WHERE IdUsuario = @ID";
                SqlCommand mySqlCommand = new SqlCommand(sql, conexao.getConnection());
                mySqlCommand.Parameters.AddWithValue("@ID", usuario.Id);
                dr = mySqlCommand.ExecuteReader();

                while (dr.Read())
                {
                    Mensagem msg = new Mensagem();

                    string texto = (string)dr["Texto"];
                    int idRemetente = (int)dr["IdRemetente"];
                    DateTime data = (DateTime)dr["Data"];
                    int id = (int)dr["IdMensagem"];
                    
                    msg.Id = id;
                    msg.Texto = texto;
                    msg.Data = data;
                    msg.Remetente = idRemetente;            

                    retorno.Add(msg);
                }
            }
            finally
            {
                if (connection != null)
                {
                    connection.Close();
                }
            }
            return retorno;
        }

        public List<Meta> buscarMetas(Usuario usuario)
        {//OK
            List<Meta> retorno = new List<Meta>();
            SqlConnection connection = null;
            try
            {
                connection = conexao.getConnection();
                connection.Open();

                SqlDataReader dr = null;
                string sql = "SELECT * FROM metas WHERE IdUsuario = @ID";
                SqlCommand mySqlCommand = new SqlCommand(sql, conexao.getConnection());
                mySqlCommand.Parameters.AddWithValue("@ID", usuario.Id);
                dr = mySqlCommand.ExecuteReader();

                while (dr.Read())
                {
                    Meta meta = new Meta();

                    string descricao = (string)dr["Descricao"];
                    int idMeta = (int)dr["IdMeta"];
                    DateTime data = new DateTime();

                    Object obj = dr.GetValue(2);
                    if (obj.ToString() != "")
                    {
                        data = (DateTime)dr["DataConquista"];
                    }
                   
                    String ficha = (String)dr.GetValue(3);
        
                    meta.Id = idMeta;
                    meta.Descricao = descricao;
                    meta.Data = data;
                    meta.Ficha = ficha;

                    retorno.Add(meta);
                }
            }
            finally
            {
                if (connection != null)
                {
                    connection.Close();
                }
            }
            return retorno;
        }

        public List<Peso> buscarPesos(Usuario usuario)
        {//OK
            List<Peso> retorno = new List<Peso>();
            SqlConnection connection = null;
            try
            {
                connection = conexao.getConnection();
                connection.Open();

                SqlDataReader dr = null;
                string sql = "SELECT * FROM peso WHERE IdUsuario = @ID";
                SqlCommand mySqlCommand = new SqlCommand(sql, conexao.getConnection());
                mySqlCommand.Parameters.AddWithValue("@ID", usuario.Id);
                dr = mySqlCommand.ExecuteReader();

                while (dr.Read())
                {
                    Peso peso = new Peso();

                    double kg = (double)dr["Kg"];
                    DateTime data = (DateTime)dr["Data"];
                    int id = (int)dr["IdPeso"];

                    peso.Data = data;
                    peso.Kilogramas = kg;
                    peso.Id = id;

                    retorno.Add(peso);
                }
            }
            finally
            {
                if (connection != null)
                {
                    connection.Close();
                }
            }
            return retorno;
        }

        public List<Refeicao> buscarRefeicao(Usuario usuario) 
        {//OK
            List<Refeicao> retorno = new List<Refeicao>();
            SqlConnection connection = null;
            try
            {
                connection = conexao.getConnection();
                connection.Open();

                SqlDataReader dr = null;
                string sql = "SELECT * FROM refeicao WHERE IdUsuario = @ID";
                SqlCommand mySqlCommand = new SqlCommand(sql, conexao.getConnection());
                mySqlCommand.Parameters.AddWithValue("@ID", usuario.Id);
                dr = mySqlCommand.ExecuteReader();

                while (dr.Read())
                {
                    Refeicao refeicao = new Refeicao();

                    int id = (int) dr["IdRefeicao"];
                    DateTime data = (DateTime) dr["Data"];
                    string tipo = (string)dr["Tipo"];
                    int calorias = (int)dr["QtdCalorias"];
                    String descricao = (String)dr["Descricao"];
                    Object obj = dr["InfoNutricionais"];
                    String infoNutricionais = "";
                    if (obj.ToString() != "") 
                    {
                        infoNutricionais = (String)dr["InfoNutricionais"];
                    }
                   
                    string nome = (string)dr["Nome"];

                    refeicao.Id = id;                
                    refeicao.Data = data;
                    refeicao.Tipo = tipo;
                    refeicao.Calorias = calorias;
                    refeicao.Descricao = descricao;
                    refeicao.infoNutricionais = infoNutricionais;
                    refeicao.Nome = nome;

                    retorno.Add(refeicao);
                }
            }
            finally
            {
                if (connection != null)
                {
                    connection.Close();
                }
            }
            return retorno;
        }

        public List<Usuario> buscarTodosMotivadores(Usuario motivado) 
        {
            List<Usuario> retorno = new List<Usuario>();
            SqlConnection connection = null;
            List<int> idsMotivadores = new List<int>();
            try
            {
                connection = conexao.getConnection();
                connection.Open();

                SqlDataReader dr = null;
                string sql = "SELECT * FROM motivacao WHERE IDUsuarioMotivado = @ID";
                SqlCommand mySqlCommand = new SqlCommand(sql, conexao.getConnection());
                mySqlCommand.Parameters.AddWithValue("@ID", motivado.Id);
                dr = mySqlCommand.ExecuteReader();
                                
                while (dr.Read())
                {
                    int idMotivador = (int)dr["IDUsuarioMotivador"];

                    idsMotivadores.Add(idMotivador);
                    
                }
            }
            finally
            {
                if (connection != null)
                {
                    connection.Close();
                }
            }

            for (int i = 0; i < idsMotivadores.Count; i++) 
            {
                Usuario usuario = this.buscarUsuarioPorId(idsMotivadores[i]);
                retorno.Add(usuario);
            }
                return retorno;
        }

        public List<Foto> buscarFotos(Usuario usuario)
        {//OK
            List<Foto> retorno = new List<Foto>();
            SqlConnection connection = null;
            try
            {
                connection = conexao.getConnection();
                connection.Open();

                SqlDataReader dr = null;
                string sql = "SELECT * FROM foto WHERE IdUsuario = @ID";
                SqlCommand mySqlCommand = new SqlCommand(sql, conexao.getConnection());
                mySqlCommand.Parameters.AddWithValue("@ID", usuario.Id);
                dr = mySqlCommand.ExecuteReader();

                while (dr.Read())
                {
                    Foto foto = new Foto();
                    
                    string descricao = (string)dr["Descricao"];
                    byte[] arquivo = (byte[])dr["Arquivo"];
                    int id = (int)dr["IDFoto"];

                    foto.ID = id;
                    foto.Descricao = descricao;
                    foto.Imagem = arquivo;

                    retorno.Add(foto);
                }
            }
            finally 
            {
                if (connection != null)
                {
                    connection.Close();
                }  
            }

            return retorno;
        }

        #endregion

        #region Metodos Privados
        private void removerTodasAtividades(Usuario usuario) 
        {           
                SqlCommand mySqlCommand = new SqlCommand();
                mySqlCommand.CommandText = "DELETE FROM atividade WHERE idUsuario = @ID";
                mySqlCommand.Parameters.AddWithValue("@ID", usuario.Id);

                conexao.executarQuery(mySqlCommand);

        }

        private void removerTodasMensagens(Usuario usuario) 
        {
            SqlCommand mySqlCommand = new SqlCommand();
            mySqlCommand.CommandText = "DELETE FROM mensagem WHERE idUsuario = @ID";
            mySqlCommand.Parameters.AddWithValue("@ID", usuario.Id);

            conexao.executarQuery(mySqlCommand);
        }

        private void removerTodasMetas(Usuario usuario) 
        {
            SqlCommand mySqlCommand = new SqlCommand();
            mySqlCommand.CommandText = "DELETE FROM metas WHERE idUsuario = @ID";
            mySqlCommand.Parameters.AddWithValue("@ID", usuario.Id);

            conexao.executarQuery(mySqlCommand);
        }

        private void removerTodosPesos(Usuario usuario) 
        {
            SqlCommand mySqlCommand = new SqlCommand();
            mySqlCommand.CommandText = "DELETE FROM peso WHERE idUsuario = @ID";
            mySqlCommand.Parameters.AddWithValue("@ID", usuario.Id);

            conexao.executarQuery(mySqlCommand);
        }

        private void removerTodasRefeicoes(Usuario usuario) 
        {
            SqlCommand mySqlCommand = new SqlCommand();
            mySqlCommand.CommandText = "DELETE FROM refeicao WHERE idUsuario = @ID";
            mySqlCommand.Parameters.AddWithValue("@ID", usuario.Id);

            conexao.executarQuery(mySqlCommand);
        }

        private void removerTodosMotivadores(Usuario usuario) 
        {
            SqlCommand mySqlCommand = new SqlCommand();
            mySqlCommand.CommandText = "DELETE FROM motivacao WHERE IDUsuarioMotivado = @ID";
            mySqlCommand.Parameters.AddWithValue("@ID", usuario.Id);

            conexao.executarQuery(mySqlCommand);
        }

        private void removerTodasFotos(Usuario usuario) 
        {
            SqlCommand mySqlCommand = new SqlCommand();
            mySqlCommand.CommandText = "DELETE FROM foto WHERE IdUsuario = @ID";
            mySqlCommand.Parameters.AddWithValue("@ID", usuario.Id);

            conexao.executarQuery(mySqlCommand);
        }

        private Usuario buscarUsuarioPorId(int id) 
        {
            Usuario retorno = new Usuario();
            SqlConnection connection = null;
            try
            {
                connection = conexao.getConnection();
                connection.Open();

                SqlDataReader dr = null;
                string sql = "SELECT * FROM usuario WHERE ID = @ID";
                SqlCommand mySqlCommand = new SqlCommand(sql, conexao.getConnection());
                mySqlCommand.Parameters.AddWithValue("@ID", id);
                dr = mySqlCommand.ExecuteReader();

                if (dr.Read())
                {
                    string nome = (string)dr["Nome"];
                    string sobrenome = (string)dr["Sobrenome"];
                    string email = (string)dr["Email"];
                    DateTime nascimento = (DateTime)dr["Nascimento"];
                    int sexo = (int)dr["Sexo"];
                    double altura = (double)dr["Altura"];

                    retorno.Nome = nome;
                    retorno.Sobrenome = sobrenome;
                    retorno.Email = email;
                    retorno.Nascimento = nascimento;
                    retorno.Sexo = sexo;
                    retorno.Altura = altura;
                    retorno.Id = id;
                }
            }
            finally
            {
                if (connection != null)
                {
                    connection.Close();
                }
            }

            Usuario user = new Usuario();
            user.Id = id;
            List<Foto> album = this.buscarFotos(user);
            retorno.Album = album;

            return retorno; 
        }
        #endregion

    }
}
